@@ -5,6 +5,10 @@
 extern "C" void wakeup_task(unsigned int key);
 
 extern Point curMouse;
+#if THREAD_DEBUG
+extern "C" void ThreadDebugMessagePrint();
+#endif
+extern int readyThreadCount;
 
 class CYieldRepeater : public LPeriodical
 {
@@ -56,7 +60,11 @@ class CYieldRepeater : public LPeriodical
 		// wakeup event_thread if exsits
 		extern LThread * event_thread;
 		if ( event_thread ) {
-			event_thread->Resume();
+			try {
+				event_thread->Resume();
+			} catch (...) {
+				::DebugStr("\pcan't resume event_thread");
+			}
 			LThread::Yield(event_thread);
 			if ( *sExitLoop ) {
 				*sExitLoop = false;
@@ -72,8 +80,13 @@ class CYieldRepeater : public LPeriodical
 		else
 		{
 			theApp->SetSleepTime(0);
+			curTick = TickCount();
+			mNextTicks = curTick + mQuantum;
 			do
 			{
+				readyThreadCount = LThread::CountReadyThreads();
+				if ( readyThreadCount == 0 )
+					break;
 				LThread::Yield();
 				if ( *sExitLoop ) {
 					*sExitLoop = false;
@@ -91,8 +104,10 @@ class CYieldRepeater : public LPeriodical
 					break;
 				}
 			} while (curTick <= mNextTicks);
-			mNextTicks = curTick + mQuantum;
 		}
+#if THREAD_DEBUG
+		ThreadDebugMessagePrint();
+#endif
 	}
   protected:
 	SInt32				mQuantum;
