@@ -1106,6 +1106,7 @@ int i;
 XLISP_ENV * env;
 RS_BUF rsb;
 XL_SEXP * ret, * last_tag;
+L_CHAR * f;
 
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
@@ -1153,10 +1154,28 @@ ss_printf("MAP--------\n");
 					ses,
 					&rsb.r->map.src,
 					&rsb.r->map.cu_src);
+				if ( rsb.r->map.cu_src.system == 0 ) {
+					f = ll_copy_str(get_url_str2(&rsb.r->map.src));
+					set_c_unit(&rsb.r->map.cu_src,
+						f,
+						l_string(std_cm,"base"),
+						l_string(std_cm,"m"));
+					rsb.r->h.flags |= RF_UNCACHE;
+					d_f_ree(f);
+				}
 				rs_cache_setup_c_unit(
 					ses,
 					&rsb.r->map.dest,
 					&rsb.r->map.cu_dest);
+				if ( rsb.r->map.cu_dest.system == 0 ) {
+					f = ll_copy_str(get_url_str2(&rsb.r->map.dest));
+					set_c_unit(&rsb.r->map.cu_dest,
+						f,
+						l_string(std_cm,"base"),
+						l_string(std_cm,"m"));
+					rsb.r->h.flags |= RF_UNCACHE;
+					d_f_ree(f);
+				}
 			}
 			wp->result = rsb.r;
 			wp->data_result = rsb.sexp;
@@ -1833,7 +1852,7 @@ printf("RESORCE CACHE INVOKE\n");
 	for ( i = 0 ; i < RES_HASH_SIZE ; ) {
 		lock_task(res_lock);
 		for ( r = res_no_hash_table[i] ; r ; r = r->h.no_next )
-			if ( (r->h.flags & (RF_CACHE|RF_COMPLETE|RF_LOAD_EXTEND_PROC))
+			if ( (r->h.flags & (RF_CACHE|RF_COMPLETE|RF_LOAD_EXTEND_PROC|RF_UNCACHE))
 					== RF_COMPLETE ) {
 				break;
 			}
