@@ -731,9 +731,9 @@ XL_SEXP * gv_set_status_coordinate();
 		goto end;
 	e_param = "pointer";
 	if ( l_strcmp(pointer,l_string(std_cm,"on")) == 0 )
-		set_pointer_indicate(IF_COORDINATE,&r->h.entry);
+		set_pointer_indicate(wf_next_gf(0,GVFM_LIVE),IF_COORDINATE,&r->h.entry);
 	else if ( l_strcmp(pointer,l_string(std_cm,"off")) == 0 )
-		set_pointer_indicate(0,&r->h.entry);
+		set_pointer_indicate(wf_next_gf(0,GVFM_LIVE),0,&r->h.entry);
 	else	goto invalid_param;
 end:
 
