@@ -279,6 +279,8 @@ int wfid;
 		case 0:
 		case WFF_PLOT:
 			change_win_flame(gf,wf,0,WFT_PLOT);
+			break;
+		default:
 			change_win_flame(gf,wf,0,WFT_STD);
 		}
 		ex_unlock(gf);
