@@ -170,30 +170,28 @@ int i,j,k,sub;
 	if ( pos < 0 )
 		start = n->start;
 	else	start = n->mp_tbl[pos].crd;
-set_cpu_msg(720024);
+/*
+if ( localhost_check_str(start,"routing_optimize_el") < 0 ) {
+	log_printf(LOG_WARNING,"REMOTE_CK_OPT pos=%i local_ptr=%i\n",
+		pos,*local_ptr);
+}
+*/
 	mpi = get_mpi(0,start,MPI_READ);
-set_cpu_msg(720025);
 	if ( mpi == 0 )
 		return;
-set_cpu_msg(720026);
 	a = get_mpi_around(mpi);
-set_cpu_msg(720027);
 	if ( a == 0 )
 		return;
 	flush_mpi(mpi);
-set_cpu_msg(720028);
 	for ( i = n->mp_ptr-1 ; i > pos+1 ; i -- ) {
 		result = cmp_around(n->mp_tbl[i].crd,a);
 		if ( result )
 			goto mutch;
 	}
-set_cpu_msg(720029);
 	free_around_list(a);
 	return;
 mutch:
 
-set_cpu_msg(720030);
-
 	sub = i - pos - 1;
 	*local_ptr -= sub;
 	for ( j = pos+1 ; j < i ; j ++ )
@@ -204,20 +202,46 @@ set_cpu_msg(720030);
 		reset_mp_entry(&n->mp_tbl[k]);
 	if ( check_map_ptr(&n->mp_tbl[pos+1]) )
 		d_f_ree(n->mp_tbl[pos+1].map);
-set_cpu_msg(720031);
 	n->mp_tbl[pos+1].map = ll_copy_str(result->map);
 	n->mp_ptr = j;
 	free_around_list(a);
-set_cpu_msg(720032);
+}
 
+int
+local_adjust(MP_T * n,int local_ptr)
+{
+L_CHAR * u_str;
+URL u;
+unsigned int ip;
+int port;
+	ip = get_localhostip();
+	port = get_my_port();
+
+	for ( ; local_ptr > 0 ; local_ptr -- ) {
+		u_str = n->mp_tbl[local_ptr-1].crd;
+		get_url2(&u,u_str);
+		if ( cmp_site(u.server,0,u.port,
+				0,ip,port) == 0 ) {
+			free_url(&u);
+			break;
+		}
+		free_url(&u);
+	}
+	return local_ptr;
 }
 
 void
 routing_optimize(MP_T * n,int local_ptr)
 {
 int i;
+
+	gc_push(0,0,"routing_optimize");
+	local_ptr = local_adjust(n,local_ptr);
+	gc_pop(0,0);
+
 	for ( i = -1 ; i < local_ptr ; i ++ )
 		routing_optimize_el(n,&local_ptr,i);
+
 }
 
 void
