@@ -63,11 +63,11 @@ int interval;
 			stab_status);
 
 /*
-	task_flag = d_alloc((cpu+1)*sizeof(int),12);
+	task_flag = d_alloc((cpu+1)*sizeof(int));
 */
-	task_timer = d_alloc((cpu+1)*sizeof(int),14);
-	task_target = d_alloc((cpu+1)*sizeof(TICK_QUE*),11);
-	thread_id = d_alloc((cpu+1)*sizeof(int),13);
+	task_timer = d_alloc((cpu+1)*sizeof(int));
+	task_target = d_alloc((cpu+1)*sizeof(TICK_QUE*));
+	thread_id = d_alloc((cpu+1)*sizeof(int));
 
 	for ( ; cpu ; cpu -- ) {
 /*
@@ -181,6 +181,12 @@ TICK_QUE * tq;
 			}
 			gc_pop(0,0);
 			exit_stabilizer('r');
+{
+char buffer[50];
+	sprintf(buffer,"gcore %i\n",getpid());
+	system(buffer);
+}
+er_panic("HANGUP");
 			exit(1);
 		}
 
