@@ -61,9 +61,15 @@ typedef struct mem_header {
 } MEM_HEADER;
 
 #define MEM_LIST_HASH_SIZE	53
+#define MEM_FREE_INFO_MAX	1000
 MEM_LIST ** mem_list_hash;
 MEM_LIST * mem_max_list;
 
+MEM_FREE_INFO ** mem_free_info_hash;
+MEM_FREE_INFO * mem_free_time_head;
+MEM_FREE_INFO * mem_free_time_tail;
+int mem_free_info_len;
+
 void ind_tick();
 void list_tick();
 
@@ -81,8 +87,12 @@ _new_mem_hash()
 {
 int i;
 	mem_list_hash = malloc(MEM_LIST_HASH_SIZE*sizeof(MEM_LIST*));
-	for ( i = 0 ; i < MEM_LIST_HASH_SIZE ; i ++ )
+	mem_free_info_hash = malloc(MEM_LIST_HASH_SIZE
+		*sizeof(MEM_FREE_INFO*));
+	for ( i = 0 ; i < MEM_LIST_HASH_SIZE ; i ++ ) {
 		mem_list_hash[i] = 0;
+		mem_free_info_hash[i] = 0;
+	}
 }
 
 MEM_LIST *
@@ -190,6 +200,51 @@ int old_size;
 	return ret;
 }
 
+void
+_delete_free_info(MEM_FREE_INFO * fi)
+{
+unsigned int key;
+MEM_FREE_INFO ** fip;
+	key = fi->ptr % MEM_LIST_HASH_SIZE;
+	fip = &mem_free_info_hash[key];
+	for ( ; *fip && *fip != fi ; fip = &(*fip)->next );
+	if ( *fip == 0 )
+		er_panic("free");
+	*fip = fi->next;
+	free(fi);
+}
+
+void
+_insert_free_info(void * ptr,char * file,int line)
+{
+unsigned int _ptr;
+MEM_FREE_INFO * fi;
+unsigned int key;
+	_ptr = (unsigned int)ptr;
+	fi = malloc(sizeof(*fi));
+	fi->ptr = _ptr;
+	fi->file = file;
+	fi->line = line;
+
+	key = _ptr % MEM_LIST_HASH_SIZE;
+	fi->next = mem_free_info_hash[key];
+	mem_free_info_hash[key] = fi;
+
+	fi->time_next = 0;
+	if ( mem_free_time_tail ) {
+		mem_free_time_tail->time_next = fi;
+		mem_free_time_tail = fi;
+	}
+	else mem_free_time_tail = mem_free_time_head = fi;
+	mem_free_info_len ++;
+	for ( ; mem_free_info_len > MEM_FREE_INFO_MAX ; ) {
+		fi = mem_free_time_head;
+		mem_free_time_head = fi->time_next;
+		_delete_free_info(fi);
+		mem_free_info_len --;
+	}
+}
+
 void xx_d_f_ree(void * ptr,char * file,int line)
 {
 MEM_HEADER * mh;
@@ -200,6 +255,7 @@ MEM_LIST * ml;
 	mh = mh - 1;
 	if ( mh->last_free_file || mh->last_free_line )
 		er_panic("xx_d_f_ree(1)");
+	_insert_free_info(ptr,file,line);
 	mh->last_free_file = file;
 	mh->last_free_line = line;
 	ml = mh->mlp;
