@@ -1,4 +1,4 @@
-/* ver.A.04(ASTROBOY) */
+/* ver.A.04.04(ASTROBOY) */
 
 
 #include "version.h"
@@ -8,8 +8,8 @@ VERSION ap_version = {
 	"AP.code",
 	"r64status",
 	"(C) 2000-2004 Hirohisa Mori And GB-group",
-	"ver.A.04(ASTROBOY)",
-	2004,2,19,
+	"ver.A.04.04(ASTROBOY)",
+	2004,4,15,
 	0,
 	"r64/cr format status checker ",
 };
