@@ -1994,10 +1994,6 @@ XL_SEXP * r, * ret;
 XL_SEXP * cmd;
 int line;
 
-void * stt, * stt_2;
-
-stt_2 = get_gc_check_point();
-
 	gc_push(0,0,"relay1"); /* section 0 level 1 */
 
 	for ( ; ; ) {
@@ -2066,12 +2062,10 @@ ss_printf("(%i)>>",get_xltime());
 print_sexp(s_stdout,r,PF_RAW_DISABLE);
 ss_printf("\n");
 */
-stt = get_gc_check_point();
 
 
 		ret = eval(xli->env,r);
 
-compare_gc_check_point("relay_eval",stt);
 
 /*
 ss_printf("(%i)>>RETURN\n",get_xltime());
@@ -2081,6 +2075,9 @@ ss_printf("\n");
 
 		gc_pop(ret,gc_gb_sexp); /* section 1 level 2 */
 
+		if ( s_exist(xli->out) == 0 )
+			break;
+
 		gc_push(ret,gc_gb_sexp,"relay3");
 
 		if ( check_delay(ret,0) == CDT_WAIT ) {
@@ -2104,7 +2101,6 @@ ss_printf("\n");
 
 	gc_pop(0,0); /* section 0 level 1 */
 
-compare_gc_check_point("relay_loop",stt_2);
 
 }
 
@@ -2329,6 +2325,12 @@ void
 _tick_check(XL_INTERPRETER * xli)
 {
 	set_xli_si(xli);
+	if ( s_exist(xli->inp) == 0 )
+		xli->inp = 0;
+	if ( s_exist(xli->out) == 0 )
+		xli->out = 0;
+	if ( s_exist(xli->err) == 0 )
+		xli->err = 0;
 	if ( xli->open_timeout &&
 			xli->open_timeout < get_xltime() ) {
 		xli->flags &= ~XIF_P_MASK;
